:mod:`ou_container_builder.packs`
=================================

.. automodule:: ou_container_builder.packs
   :members:

.. toctree::
    :maxdepth: 1

    packs/code_server
    packs/jupyterlab
    packs/mariadb
    packs/nbclassic
    packs/tutorial_server
